%%
%% This is file `amigapl.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% strony.dtx  (with options: `amigapl')
%% 
%% This is a generated file.
%% 
%% Copyright (C) 1994 by Mariusz Olko.  All rights reserved.
%% Copyright (C) 1997, 1998 by Mariusz Olko and Marcin Woli\'nski.
%% Copyright (C) 2000, 2002, 2003, 2007, 2017, 2021 by Marcin Woli\'nski.
%% 
%% 
%% This file is part of the package `Polski'
%% -----------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.2
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.2 or later is part of all distributions of LaTeX
%% version 1999/12/01 or later.
%% 
%% This file may only be distributed together with a copy of the 'Polski'
%% package.
%% 
\ProvidesFile{amigapl.def}
\DeclareInputText{194}{\k A}
\DeclareInputText{202}{\@tabacckludge'C}
\DeclareInputText{203}{\k E}
\DeclareInputText{206}{\L}
\DeclareInputText{207}{\@tabacckludge'N}
\DeclareInputText{211}{\@tabacckludge'O}
\DeclareInputText{212}{\@tabacckludge'S}
\DeclareInputText{218}{\@tabacckludge'Z}
\DeclareInputText{219}{\.Z}
\DeclareInputText{226}{\k a}
\DeclareInputText{234}{\@tabacckludge'c}
\DeclareInputText{235}{\k e}
\DeclareInputText{238}{\l}
\DeclareInputText{239}{\@tabacckludge'n}
\DeclareInputText{243}{\@tabacckludge'o}
\DeclareInputText{244}{\@tabacckludge's}
\DeclareInputText{250}{\@tabacckludge'z}
\DeclareInputText{251}{\.z}
\endinput
%%
%% End of file `amigapl.def'.
