%%
%% This is file `qxenc.def',
%% generated with the docstrip utility.
%%
%% The original source files were:
%%
%% strony.dtx  (with options: `qx')
%% 
%% This is a generated file.
%% 
%% Copyright (C) 1994 by Mariusz Olko.  All rights reserved.
%% Copyright (C) 1997, 1998 by Mariusz Olko and Marcin Woli\'nski.
%% Copyright (C) 2000, 2002, 2003, 2007, 2017, 2021 by Marcin Woli\'nski.
%% 
%% 
%% This file is part of the package `Polski'
%% -----------------------------------------
%% 
%% It may be distributed and/or modified under the
%% conditions of the LaTeX Project Public License, either version 1.2
%% of this license or (at your option) any later version.
%% The latest version of this license is in
%%    http://www.latex-project.org/lppl.txt
%% and version 1.2 or later is part of all distributions of LaTeX
%% version 1999/12/01 or later.
%% 
%% This file may only be distributed together with a copy of the 'Polski'
%% package.
%% 
\ProvidesFile{qxenc.def}[2002/01/11 v0.05a QX font encoding definition]
\DeclareFontEncoding{QX}{}{}
\DeclareFontSubstitution{QX}{qtm}{m}{n}
\DeclareTextSymbol{\textalpha}{QX}{0}
\DeclareTextSymbol{\textDelta}{QX}{1}           % TeX-math, Adobe
\DeclareTextSymbol{\textbeta}{QX}{2}            % TeX-math, Adobe
\DeclareTextSymbol{\textdelta}{QX}{3}           % TeX-math, Adobe
\DeclareTextSymbol{\textpi}{QX}{4}              % TeX-math, Adobe
\DeclareTextSymbol{\textPi}{QX}{5}              % TeX-math, Adobe
\DeclareTextSymbol{\textSigma}{QX}{6}           % TeX-math, Adobe
\DeclareTextSymbol{\textmu}{QX}{7}              % TeX-math, Adobe
\DeclareTextSymbol{\textellipsis}{QX}{8}        % LaTeX

\DeclareTextSymbol{\textOmega}{QX}{10}          % TeX-math, Adobe

\DeclareTextSymbol{\i}{QX}{16}                  % TeX
\DeclareTextComposite{\.}{QX}{i}{`\i}           % LaTeX
\DeclareTextSymbol{\j}{QX}{17}                  % TeX
\DeclareTextAccent{\`}{QX}{18}                  % TeX
\DeclareTextAccent{\'}{QX}{19}                  % TeX
\DeclareTextAccent{\v}{QX}{20}                  % TeX
\DeclareTextAccent{\u}{QX}{21}                  % TeX
\DeclareTextAccent{\=}{QX}{22}             % MeX
\DeclareTextCommand{\b}{QX}[1]
   {\leavevmode\bgroup\o@lign{\relax#1\crcr\hidewidth\sh@ft{29}%
     \vbox to.2ex{\hbox{\char22}\vss}\hidewidth}\egroup}
\DeclareTextAccent{\r}{QX}{23}                  % LaTeX
\DeclareTextCommand{\c}{QX}[1]                  % TeX
   {\leavevmode\setbox\z@\hbox{#1}\ifdim\ht\z@=1ex\accent24 #1%
    \else{\ooalign{\unhbox\z@\crcr\hidewidth\char24\hidewidth}}\fi}
\DeclareTextSymbol{\ss}{QX}{25}                 % TeX
\DeclareTextSymbol{\ae}{QX}{26}                 % TeX
\DeclareTextSymbol{\oe}{QX}{27}                 % TeX
\DeclareTextSymbol{\o}{QX}{28}                  % TeX
\DeclareTextSymbol{\AE}{QX}{29}                 % TeX
\DeclareTextSymbol{\OE}{QX}{30}                 % TeX
\DeclareTextSymbol{\O}{QX}{31}                  % TeX

\DeclareTextSymbol{\textquotedblright}{QX}{34}  % LaTeX
\DeclareTextSymbol{\textdollar}{QX}{36}         % LaTeX
\DeclareTextSymbol{\textquoteright}{QX}{39}     % LaTeX

\DeclareTextCommand{\d}{QX}[1]                % TeX
   {\leavevmode\bgroup
    \o@lign{\relax#1\crcr\hidewidth\sh@ft{10}.\hidewidth}\egroup} % \char46

\DeclareTextSymbol{\textexclamdown}{QX}{60}     % LaTeX
\DeclareTextSymbol{\textquestiondown}{QX}{62}   % LaTeX

\DeclareTextSymbol{\textquotedblleft}{QX}{92}   % LaTeX
\DeclareTextAccent{\^}{QX}{94}                  % TeX
\DeclareTextAccent{\.}{QX}{95}                  % TeX

\DeclareTextSymbol{\textquoteleft}{QX}{96}      % LaTeX
\DeclareTextSymbol{\textendash}{QX}{123}        % LaTeX
\DeclareTextSymbol{\textemdash}{QX}{124}        % LaTeX
\DeclareTextAccent{\H}{QX}{125}                 % TeX
\DeclareTextAccent{\~}{QX}{126}                 % TeX
\DeclareTextAccent{\"}{QX}{127}                 % TeX

\DeclareTextSymbol{\texteuro}{QX}{128}          % LaTeX (TS1 ?)
\DeclareTextSymbol{\textEuro}{QX}{128}          % Adobe's name is `Euro'
\DeclareTextComposite{\k}{QX}{A}{129}
\DeclareTextComposite{\'}{QX}{C}{130}
\DeclareTextSymbol{\textgreater}{QX}{131}       % LaTeX
\DeclareTextSymbol{\textxgeq}{QX}{132}          % MeX-math
\DeclareTextSymbol{\textapprox}{QX}{133}        % TeX-math
\DeclareTextComposite{\k}{QX}{E}{134}
\DeclareTextComposite{\k}{QX}{I}{135}

\DeclareTextSymbol{\textless}{QX}{136}          % LaTeX
\DeclareTextSymbol{\textxleq}{QX}{137}          % MeX-math
\DeclareTextSymbol{\L}{QX}{138}                 % TeX
\DeclareTextComposite{\'}{QX}{N}{139}
\DeclareTextSymbol{\textasciitilde}{QX}{140}    % LaTeX
\DeclareTextSymbol{\textasciicircum}{QX}{141}   % LaTeX
\DeclareTextSymbol{\textell}{QX}{142}           % TeX-math, Adobe
\DeclareTextSymbol{\textdagger}{QX}{143}        % LaTeX
\DeclareTextSymbol{\textdaggerdbl}{QX}{144}     % LaTeX
\DeclareTextComposite{\'}{QX}{S}{145}
\DeclareTextComposite{\v}{QX}{S}{146}
\DeclareTextComposite{\c}{QX}{S}{147}
\DeclareTextSymbol{\textdegree}{QX}{148}        % Adobe
\DeclareTextComposite{\c}{QX}{T}{149}
\DeclareTextCommand{\k}{QX}[1]{%                % LaTeX
  \leavevmode\setbox0=\hbox{#1}\ifdim\ht0=1ex \accent150 #1%
  \else{\ooalign{\hidewidth\char150\hidewidth\crcr\unhbox0}}\fi
  }
\DeclareTextComposite{\k}{QX}{U}{151}
\DeclareTextComposite{\"}{QX}{Y}{152}
\DeclareTextComposite{\'}{QX}{Z}{153}
\DeclareTextComposite{\v}{QX}{Z}{154}
\DeclareTextComposite{\.}{QX}{Z}{155}

\DeclareTextSymbol{\textbraceleft}{QX}{157}     % LaTeX
\DeclareTextSymbol{\textbraceright}{QX}{158}    % LaTeX
\DeclareTextSymbol{\textsection}{QX}{159}       % LaTeX

\DeclareTextComposite{\k}{QX}{a}{161}
\DeclareTextComposite{\'}{QX}{c}{162}
\DeclareTextSymbol{\textregistered}{QX}{163}    % LaTeX
\DeclareTextSymbol{\copyright}{QX}{164}         % TeX
\DeclareTextSymbol{\textdiv}{QX}{165}           % TeX-math
\DeclareTextComposite{\k}{QX}{e}{166}
\DeclareTextComposite{\k}{QX}{i}{167}
\DeclareTextSymbol{\textminus}{QX}{168}         % Adobe
\DeclareTextSymbol{\texttimes}{QX}{169}         % TeX-math
\DeclareTextSymbol{\l}{QX}{170}                 % TeX
\DeclareTextComposite{\'}{QX}{n}{171}
\DeclareTextSymbol{\textpm}{QX}{172}            % TeX-math
\DeclareTextSymbol{\textinfty}{QX}{173}         % TeX-math
\DeclareTextSymbol{\guillemotleft}{QX}{174}     % LaTeX
\DeclareTextSymbol{\guillemotright}{QX}{175}    % LaTeX
\DeclareTextSymbol{\textparagraph}{QX}{176}     % LaTeX
\DeclareTextComposite{\'}{QX}{s}{177}
\DeclareTextComposite{\v}{QX}{s}{178}
\DeclareTextComposite{\c}{QX}{s}{179}
\DeclareTextSymbol{\textbullet}{QX}{180}        % LaTeX
\DeclareTextComposite{\c}{QX}{t}{181}

\DeclareTextComposite{\k}{QX}{u}{183}
\DeclareTextComposite{\"}{QX}{y}{184}
\DeclareTextComposite{\'}{QX}{z}{185}
\DeclareTextComposite{\v}{QX}{z}{186}
\DeclareTextComposite{\.}{QX}{z}{187}
\DeclareTextSymbol{\textperiodcentered}{QX}{189}% LaTeX
\DeclareTextSymbol{\textquotedbl}{QX}{190}      % LaTeX
\DeclareTextSymbol{\textquotesingle}{QX}{191}   % Adobe
\DeclareTextComposite{\`}{QX}{A}{192}
\DeclareTextComposite{\'}{QX}{A}{193}
\DeclareTextComposite{\^}{QX}{A}{194}
\DeclareTextComposite{\~}{QX}{A}{195}
\DeclareTextComposite{\"}{QX}{A}{196}
\DeclareTextSymbol{\AA}{QX}{197}                % TeX
\DeclareTextSymbol{\textbackslash}{QX}{198}     % LaTeX
\DeclareTextComposite{\c}{QX}{C}{199}

\DeclareTextComposite{\`}{QX}{E}{200}
\DeclareTextComposite{\'}{QX}{E}{201}
\DeclareTextComposite{\^}{QX}{E}{202}
\DeclareTextComposite{\"}{QX}{E}{203}
\DeclareTextComposite{\`}{QX}{I}{204}
\DeclareTextComposite{\'}{QX}{I}{205}
\DeclareTextComposite{\^}{QX}{I}{206}
\DeclareTextComposite{\"}{QX}{I}{207}

\DeclareTextSymbol{\DH}{QX}{208}                % LaTeX
\DeclareTextSymbol{\DJ}{QX}{208}                % LaTeX
\DeclareTextComposite{\~}{QX}{N}{209}
\DeclareTextComposite{\`}{QX}{O}{210}
\DeclareTextComposite{\'}{QX}{O}{211}
\DeclareTextComposite{\^}{QX}{O}{212}
\DeclareTextComposite{\~}{QX}{O}{213}
\DeclareTextComposite{\"}{QX}{O}{214}
\DeclareTextSymbol{\textcurrency}{QX}{215}      % Adobe

\DeclareTextSymbol{\textperthousand}{QX}{216}   % Adobe
\DeclareTextComposite{\`}{QX}{U}{217}
\DeclareTextComposite{\'}{QX}{U}{218}
\DeclareTextComposite{\^}{QX}{U}{219}
\DeclareTextComposite{\"}{QX}{U}{220}
\DeclareTextComposite{\'}{QX}{Y}{221}
\DeclareTextSymbol{\TH}{QX}{222}                % LaTeX
\DeclareTextSymbol{\textbar}{QX}{223}           % LaTeX

\DeclareTextComposite{\`}{QX}{a}{224}
\DeclareTextComposite{\'}{QX}{a}{225}
\DeclareTextComposite{\^}{QX}{a}{226}
\DeclareTextComposite{\~}{QX}{a}{227}
\DeclareTextComposite{\"}{QX}{a}{228}
\DeclareTextSymbol{\aa}{QX}{229}                % TeX
\DeclareTextComposite{\r}{QX}{a}{229}
\DeclareTextSymbol{\textunderscore}{QX}{230}    % LaTeX
\DeclareTextComposite{\c}{QX}{c}{231}

\DeclareTextComposite{\`}{QX}{e}{232}
\DeclareTextComposite{\'}{QX}{e}{233}
\DeclareTextComposite{\^}{QX}{e}{234}
\DeclareTextComposite{\"}{QX}{e}{235}
\DeclareTextComposite{\`}{QX}{i}{236}
\DeclareTextComposite{\`}{QX}{\i}{236}
\DeclareTextComposite{\'}{QX}{i}{237}
\DeclareTextComposite{\'}{QX}{\i}{237}
\DeclareTextComposite{\^}{QX}{i}{238}
\DeclareTextComposite{\^}{QX}{\i}{238}
\DeclareTextComposite{\"}{QX}{i}{239}
\DeclareTextComposite{\"}{QX}{\i}{239}

\DeclareTextSymbol{\dh}{QX}{240}                % LaTeX
\DeclareTextSymbol{\dj}{QX}{240}                % LaTeX
\DeclareTextComposite{\~}{QX}{n}{241}
\DeclareTextComposite{\`}{QX}{o}{242}
\DeclareTextComposite{\'}{QX}{o}{243}
\DeclareTextComposite{\^}{QX}{o}{244}
\DeclareTextComposite{\~}{QX}{o}{245}
\DeclareTextComposite{\"}{QX}{o}{246}
\DeclareTextSymbol{\textanglearc}{QX}{247}      % Adobe

\DeclareTextSymbol{\textdiameter}{QX}{248}      % Adobe
\DeclareTextComposite{\`}{QX}{u}{249}
\DeclareTextComposite{\'}{QX}{u}{250}
\DeclareTextComposite{\^}{QX}{u}{251}
\DeclareTextComposite{\"}{QX}{u}{252}
\DeclareTextComposite{\'}{QX}{y}{253}
\DeclareTextSymbol{\th}{QX}{254}                % LaTeX
\DeclareTextSymbol{\quotedblbase}{QX}{255}      % LaTeX
\endinput
%%
%% End of file `qxenc.def'.
